@@ -628,6 +628,8 @@ gail_window_get_size (AtkComponent *component,
   *height = rect.height;
 }
 
+#if defined (GDK_WINDOWING_X11)
+
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
@@ -1018,3 +1020,25 @@ gail_window_get_mdi_zorder (AtkComponent *component)
 
   return get_window_zorder (widget->window);
 }
+
+#elif defined (GDK_WINDOWING_WIN32)
+
+static gint
+gail_window_get_mdi_zorder (AtkComponent *component)
+{
+  GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
+
+  if (widget == NULL)
+    /*
+     * State is defunct
+     */
+    return -1;
+
+  g_return_val_if_fail (GTK_IS_WINDOW (widget), -1);
+
+  return 0;			/* Punt, FIXME */
+}
+
+#else
+#error Port to this GDK backend
+#endif
